@@ -2,7 +2,8 @@ from .display import ui
 from .imap import ImapConnection
 from os import path, remove, listdir
 
-if __name__ == '__main__':
+
+def shell():
     # Welcome message
     print('\n--- PyMailOrganizer --- Python command line mail organizer ---\n')
 
@@ -22,4 +23,8 @@ if __name__ == '__main__':
             remove(path.join(current_dir, file))
 
     # Termination message
-    print('\nThank you for using PyMailOrganizer!\n')
\ No newline at end of file
+    print('\nThank you for using PyMailOrganizer!\n')
+
+
+if __name__ == '__main__':
+    shell()
\ No newline at end of file
